==> flutter_flicker-0.70.0.tar.gz: lib/controls/form_input/dropdown.dart <==
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:flutter_flicker/configuration/configuration.dart';

class FlickerDropDown<T> extends StatelessWidget {
  FlickerDropDown({
    Key? key,
    required this.labelText,
    this.initialSelection,
    this.items,
    required this.onChanged,
    this.validator,
    this.optionTitles,
    this.readOnly = false,
  }) : super(key: key);

  final List<T>? items;
  final T? initialSelection;
  final String labelText;
  final ValueChanged<T?> onChanged;
  final Function? validator;
  final List<String>? optionTitles;
  final bool readOnly;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 250,
      margin: const EdgeInsets.only(
        top: 3.0,
        right: 8.0,
      ),
      alignment: Alignment.center,
      child: DropdownButtonFormField<T>(
        items: buildItemList(),
        value: initialSelection,
        onChanged: readOnly ? null : onChanged,
        validator: validator as String? Function(T?)?,
        isExpanded: true,
        decoration: InputDecoration(
          contentPadding: EdgeInsets.only(top: 25, bottom: 10),
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          disabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: Colors.transparent,
              width: 0.0,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlBorder,
            ),
          ),
          labelText: labelText.toUpperCase(),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          hintText: 'Select a $labelText',
          hintStyle: GoogleFonts.barlow(
            fontSize: 15,
            color: FlickerConfiguration.colors.hintText,
            height: 1.0,
          ),
          labelStyle: GoogleFonts.barlow(
              fontSize: 18,
              fontWeight: FontWeight.w600,
              color: FlickerConfiguration.colors.inputLabel,
              height: 0.5),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
        ),
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: FlickerConfiguration.colors.input,
          height: 1.0,
        ),
      ),
    );
  }

  List<DropdownMenuItem<T>> buildItemList() {
    var itemList = <DropdownMenuItem<T>>[];
    for (var i = 0; i < items!.length; i++) {
      itemList.add(DropdownMenuItem<T>(
        child: Text(
            optionTitles == null ? items![i].toString() : optionTitles![i]),
        value: items![i],
      ));
    }
    return itemList;
  }
}

==> flutter_flicker-0.73.0.tar.gz: lib/controls/form_input/dropdown.dart <==
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:flutter_flicker/configuration/configuration.dart';

class FlickerDropDown<T> extends StatelessWidget {
  FlickerDropDown({
    Key? key,
    required this.labelText,
    this.initialSelection,
    this.items,
    required this.onChanged,
    this.validator,
    this.optionTitles,
    this.readOnly = false,
    this.hintText,
  }) : super(key: key);

  final List<T>? items;
  final T? initialSelection;
  final String labelText;
  final ValueChanged<T?> onChanged;
  final Function? validator;
  final List<String>? optionTitles;
  final bool readOnly;
  final String? hintText;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 250,
      margin: const EdgeInsets.only(
        top: 3.0,
        right: 8.0,
      ),
      alignment: Alignment.center,
      child: DropdownButtonFormField<T>(
        items: buildItemList(),
        value: initialSelection,
        onChanged: readOnly ? null : onChanged,
        validator: validator as String? Function(T?)?,
        isExpanded: true,
        decoration: InputDecoration(
          contentPadding: EdgeInsets.only(top: 25, bottom: 10),
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          disabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: Colors.transparent,
              width: 0.0,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlBorder,
            ),
          ),
          labelText: labelText.toUpperCase(),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          hintText: hintText ?? 'Select a $labelText',
          hintStyle: GoogleFonts.barlow(
            fontSize: 15,
            color: FlickerConfiguration.colors.hintText,
            height: 1.0,
          ),
          labelStyle: GoogleFonts.barlow(
              fontSize: 18,
              fontWeight: FontWeight.w600,
              color: FlickerConfiguration.colors.inputLabel,
              height: 0.5),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
        ),
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: FlickerConfiguration.colors.input,
          height: 1.0,
        ),
      ),
    );
  }

  List<DropdownMenuItem<T>> buildItemList() {
    var itemList = <DropdownMenuItem<T>>[];
    for (var i = 0; i < items!.length; i++) {
      itemList.add(DropdownMenuItem<T>(
        child: Text(
            optionTitles == null ? items![i].toString() : optionTitles![i]),
        value: items![i],
      ));
    }
    return itemList;
  }
}
